#!/bin/sh /usr/share/centrifydc/perl/run

use strict;
use lib '/usr/share/centrifydc/perl';

use CentrifyDC::GP::Mapper;
use CentrifyDC::GP::GPIsolation qw(GetRegKey GetRegValType);

my $file;
my $action;
my $user;
$file = {
    'comment_markers' => [
      '#',
    ],
    'hierarchy_separator' => '.',
    'list_expr' => ', *| +',
    'list_separator' => ', ',
    'lock' => '/etc/centrifydc/centrifydc.conf.lock',
    'match_expr' => [
      '/^\s*([^\s:=]+)[:=]\s*(.*)/',
    ],
    'named_list_separator' => ',',
    'parent_expr' => '^(.*)\.([^\.]+)$',
    'path' => [
      '/etc/centrifydc/centrifydc.conf',
    ],
    'post_action' => [
      'DO_ADRELOAD',
    ],

    'value_map' => {

      'adclient.sntp.enabled' => {
        'default_data' => '0',
        'file_valueoff' => 'false',
        'file_valueon' => 'true',
        'reg_class' => 'machine',
        'reg_key' => GetRegKey('adclient.sntp.enabled'),
        'reg_type' => [
          'REG_DWORD',
        ],
        'reg_value' => 'Enabled',
        'value_type' => 'named',
        'valueoff' => '0',
        'valueon' => '1',
      },

      'adclient.sntp.poll' => {
        'default_data' => '0',
        'reg_class' => 'machine',
        'reg_key' => GetRegKey('adclient.sntp.enabled'),
        'reg_type' => [
          'REG_DWORD',
        ],
        'reg_value' => 'MaxPollInterval',
        'value_type' => 'named',
      },

      'gp.refresh.disable' => {
        'default_data' => '0',
        'file_valueoff' => 'false',
        'file_valueon' => 'true',
        'reg_class' => 'machine',
        'reg_key' => GetRegKey('gp.refresh.disable'),
        'reg_type' => [
          'REG_DWORD',
        ],
        'reg_value' => 'DisableBkGndGroupPolicy',
        'value_type' => 'named',
      },

      'pam.password.expiry.warn' => {
        'default_data' => '14',
        'reg_class' => 'machine',
        'reg_key' => GetRegKey('pam.password.expiry.warn'),
        'reg_type' => [
          'REG_DWORD',
        ],
        'reg_value' => 'PasswordExpiryWarning',
        'value_type' => 'named',
      },

      'secedit.system.access.lockoutbadcount' => {
        'reg_class' => 'machine',
        'reg_key' => GetRegKey('secedit.system.access.lockoutbadcount'),
        'reg_type' => [
          GetRegValType('secedit.system.access.lockoutbadcount'),
        ],
        'reg_value' => 'LockoutBadCount',
        'value_type' => 'named',
      },

      'secedit.system.access.lockoutduration' => {
        'reg_class' => 'machine',
        'reg_key' => GetRegKey('secedit.system.access.lockoutduration'),
        'reg_type' => [
          GetRegValType('secedit.system.access.lockoutduration'),
        ],
        'reg_value' => 'LockoutDuration',
        'reg_data_expr' => [
          '$data = ($data eq "0") ? -1 : $data',
        ],
        'value_type' => 'named',
      },

      'secedit.system.access.maximumpasswordage' => {
        'reg_class' => 'machine',
        'reg_key' => GetRegKey('secedit.system.access.maximumpasswordage'),
        'reg_type' => [
          GetRegValType('secedit.system.access.maximumpasswordage'),
        ],
        'reg_value' => 'MaximumPasswordAge',
        'reg_data_expr' => [
          '$data = ($data eq "0") ? -1 : $data',
        ],
        'value_type' => 'named',
      },

      'secedit.system.access.minimumpasswordage' => {
        'reg_class' => 'machine',
        'reg_key' => GetRegKey('secedit.system.access.minimumpasswordage'),
        'reg_type' => [
          GetRegValType('secedit.system.access.minimumpasswordage'),
        ],
        'reg_value' => 'MinimumPasswordAge',
        'value_type' => 'named',
      },

    },

    'write_data' => '$value: $data\n',
};

$action = $ARGV[0];
my $mode = $ARGV[2] ? $ARGV[2] : $ARGV[1];
$user = $ARGV[2] ? $ARGV[1] : undef;

if ($action eq "unmap")
{

    CentrifyDC::GP::Mapper::UnMap($file, $user);
}
else
{
    CentrifyDC::GP::Mapper::Map($file, $user);
}
